@@ -6,6 +6,7 @@
 时间：2020-06-28
 """
 import os
+import sys
 import json
 from pathlib import Path
 from typing import Union
@@ -24,9 +25,11 @@ def get_cache_obj(db_index: int = 15):
     try:
         _redis = MyRedis(db_index)
     except Exception as _e:
-        logger.exception(_e)
-        caller_info = get_caller_info(2)
-        __cache_path__ = Path(caller_info["file_abs_path"]).parent / "MySession.json"
+        if sys.platform == "win32":
+            _target_path = Path(os.environ["USERPROFILE"])
+        else:
+            _target_path = Path(os.environ["HOME"])
+        __cache_path__ = _target_path / "MySession.json"
         logger.warning(f"redis缓存不可用，启动本地文件缓存：{__cache_path__}")
         return MyCache(__cache_path__)
     else:
